plugins.debate.rooms package
============================

Submodules
----------

plugins.debate.rooms.data module
--------------------------------

.. automodule:: plugins.debate.rooms.data
   :members:
   :undoc-members:
   :show-inheritance:

plugins.debate.rooms.interface module
-------------------------------------

.. automodule:: plugins.debate.rooms.interface
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: plugins.debate.rooms
   :members:
   :undoc-members:
   :show-inheritance:
